@@ -27,14 +27,17 @@
 import os
 
 from pyworkflow.protocol import STEPS_PARALLEL
-from pyworkflow.constants import BETA
+from pyworkflow.constants import BETA, SCIPION_DEBUG_NOCLEAN
 import pyworkflow.protocol.params as params
 import pyworkflow.utils as pwutils
 from pwem.protocols import EMProtocol
+from pwem.objects import CTFModel
+from pwem import emlib
 
 from .program_ctffind import ProgramCtffind
+from ..convert import readCtfModelStack, parseCtffind4Output
 
-from tomo.objects import CTFTomo
+from tomo.objects import CTFTomo, SetOfCTFTomoSeries
 from tomo.protocols import ProtTsEstimateCTF
 
 
@@ -42,11 +45,13 @@ class CistemProtTsCtffind(ProtTsEstimateCTF):
     """ CTF estimation on a set of tilt series using CTFFIND4. """
     _label = 'tilt-series ctffind4'
     _devStatus = BETA
+    _possibleOutputs = {'outputSetOfCTFTomoSeries': SetOfCTFTomoSeries}
 
     def __init__(self, **kwargs):
         EMProtocol.__init__(self, **kwargs)
         self.stepsExecutionMode = STEPS_PARALLEL
         self.usePowerSpectra = False
+        self.useStacks = True
 
     # -------------------------- DEFINE param functions -----------------------
     def _initialize(self):
@@ -54,12 +59,12 @@ class CistemProtTsCtffind(ProtTsEstimateCTF):
         self._ctfProgram = ProgramCtffind(self)
 
     def _defineProcessParams(self, form):
-        form.addParam('recalculate', params.BooleanParam, default=False,
-                      condition='recalculate',
-                      label="Do recalculate ctf?")
-        form.addParam('continueRun', params.PointerParam, allowsNull=True,
-                      condition='recalculate', label="Input previous run",
-                      pointerClass='ProtTsCtffind')
+        form.addHidden('recalculate', params.BooleanParam, default=False,
+                       condition='recalculate',
+                       label="Do recalculate ctf?")
+        form.addHidden('continueRun', params.PointerParam, allowsNull=True,
+                       condition='recalculate', label="Input previous run",
+                       pointerClass='ProtTsCtffind')
         form.addHidden('sqliteFile', params.FileParam,
                        condition='recalculate',
                        allowsNull=True)
@@ -68,30 +73,42 @@ class CistemProtTsCtffind(ProtTsEstimateCTF):
         ProgramCtffind.defineProcessParams(form)
 
     # --------------------------- STEPS functions -----------------------------
-    def _estimateCtf(self, workingDir, tiFn, ti):
+    def processTiltSeriesStep(self, tsId):
+        """ Run ctffind on a whole TS stack at once. """
+        ts = self._getTiltSeries(tsId)
+        tsInputFn = ts.getFirstItem().getFileName()
+        tsFn = self._getTmpPath(tsId + ".mrcs")
+
+        if pwutils.getExt(tsInputFn) in ['.mrc', '.st', '.mrcs']:
+            pwutils.createAbsLink(os.path.abspath(tsInputFn), tsFn)
+        else:
+            ih = emlib.image.ImageHandler()
+            ih.convert(tsInputFn, tsFn, emlib.DT_FLOAT)
+
+        outputLog = self._getExtraPath(tsId + "_ctf.txt")
+        outputPsd = outputLog.replace(".txt", ".mrcs")
+
+        program, args = self._ctfProgram.getCommand(
+            micFn=tsFn,
+            powerSpectraPix=None,
+            ctffindOut=outputLog,
+            ctffindPSD=outputPsd)
+
         try:
-            tsId = ti.getTsId()
-            pwutils.makePath(self._getExtraPath(tsId))
-
-            outputLog = os.path.join(workingDir, 'output-log.txt')
-            outputPsd = os.path.join(workingDir, self.getPsdName(ti))
-
-            program, args = self._ctfProgram.getCommand(
-                micFn=tiFn,
-                powerSpectraPix=None,
-                ctffindOut=outputLog,
-                ctffindPSD=outputPsd)
-
             self.runJob(program, args)
+            ctfResult = parseCtffind4Output(outputLog)
+            ctf = CTFModel()
 
-            # Move files we want to keep
-            pwutils.moveFile(outputPsd, self._getExtraPath(tsId))
-            pwutils.moveFile(outputPsd.replace('.mrc', '.txt'),
-                             self._getTmpPath())
-            pwutils.moveFile(outputPsd.replace('.mrc', '_avrot.txt'),
-                             self._getExtraPath(tsId))
-        except:
-            print("ERROR: Ctffind has failed for %s" % tiFn)
+            for i, ti in enumerate(self._tsDict.getTiList(tsId)):
+                ti.setCTF(self.getCtfTi(ctf, ctfResult, i, outputPsd))
+
+            if not pwutils.envVarOn(SCIPION_DEBUG_NOCLEAN):
+                pwutils.cleanPath(tsFn)
+                pwutils.cleanPath(outputLog)
+
+            self._tsDict.setFinished(tsId)
+        except Exception as e:
+            self.error(f"ERROR: Ctffind has failed for {tsFn}: {e}")
 
     # --------------------------- INFO functions ------------------------------
     def _validate(self):
@@ -115,15 +132,15 @@ class CistemProtTsCtffind(ProtTsEstimateCTF):
         return ["Mindell2003", "Rohou2015"]
 
     # --------------------------- UTILS functions -----------------------------
-    def getPsdName(self, ti):
-        return '%s_PSD.mrc' % self.getTiPrefix(ti)
+    def _doInsertTiltImageSteps(self):
+        """ Default True, but if return False, the steps for each
+        TiltImage will not be inserted. """
+        return False
 
-    def getCtf(self, ti):
+    def getCtfTi(self, ctf, ctfArray, tiIndex, psdStack):
         """ Parse the CTF object estimated for this Tilt-Image. """
-        psd = self.getPsdName(ti)
-        outCtf = self._getTmpPath(psd.replace('.mrc', '.txt'))
-        ctfModel = self._ctfProgram.parseOutputAsCtf(outCtf,
-                                                     psdFile=self._getExtraPath(ti.getTsId(), psd))
-        ctfTomo = CTFTomo.ctfModelToCtfTomo(ctfModel)
+        readCtfModelStack(ctf, ctfArray, item=tiIndex)
+        ctf.setPsdFile(f"{tiIndex+1}@" + psdStack)
+        ctfTomo = CTFTomo.ctfModelToCtfTomo(ctf)
 
         return ctfTomo
